@@ -26,6 +26,34 @@ class PostgresClient(AbstractClient):
     _service = 'postgres'
 
 
+    def AddDBInstanceToReadOnlyGroup(self, request):
+        """This API is used to add a read-only replica to an RO group.
+
+        :param request: Request instance for AddDBInstanceToReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.AddDBInstanceToReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.AddDBInstanceToReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AddDBInstanceToReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AddDBInstanceToReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CloseDBExtranetAccess(self, request):
         """This API is used to disable the public network link to an instance.
 
@@ -54,6 +82,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CloseServerlessDBExtranetAccess(self, request):
+        """This API is used to disable public network access for a PostgreSQL for Serverless instance.
+
+        :param request: Request instance for CloseServerlessDBExtranetAccess.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CloseServerlessDBExtranetAccessRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CloseServerlessDBExtranetAccessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CloseServerlessDBExtranetAccess", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CloseServerlessDBExtranetAccessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateDBInstances(self, request):
         """This API is used to create one or more TencentDB for PostgreSQL instances.
 
@@ -82,6 +138,62 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateReadOnlyDBInstance(self, request):
+        """This API is used to create read-only replicas.
+
+        :param request: Request instance for CreateReadOnlyDBInstance.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyDBInstanceRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateReadOnlyDBInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReadOnlyDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateReadOnlyGroup(self, request):
+        """This API is used to create an RO group.
+
+        :param request: Request instance for CreateReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateServerlessDBInstance(self, request):
         """This API is used to create a PostgreSQL for Serverless instance. If the creation succeeds, the instance ID will be returned.
 
@@ -110,6 +222,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteReadOnlyGroup(self, request):
+        """This API is used to delete an RO group.
+
+        :param request: Request instance for DeleteReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DeleteReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DeleteReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteServerlessDBInstance(self, request):
         """This API is used to delete a PostgreSQL for Serverless instance.
 
@@ -418,6 +558,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeReadOnlyGroups(self, request):
+        """This API is used to query RO group information by specifying the primary instance IDs.
+
+        :param request: Request instance for DescribeReadOnlyGroups.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeReadOnlyGroupsRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DescribeReadOnlyGroupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeReadOnlyGroups", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeReadOnlyGroupsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRegions(self, request):
         """This API is used to query the purchasable regions.
 
@@ -503,7 +671,7 @@ class PostgresClient(AbstractClient):
 
 
     def DestroyDBInstance(self, request):
-        """This API is used to terminate the instance corresponding to a specified `DBInstanceId`.
+        """This API is used to terminate a pay-as-you-go instance by specifying the `DBInstanceId` parameter.
 
         :param request: Request instance for DestroyDBInstance.
         :type request: :class:`tencentcloud.postgres.v20170312.models.DestroyDBInstanceRequest`
@@ -698,6 +866,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyDBInstanceReadOnlyGroup(self, request):
+        """This API is used to modify the RO group of an instance.
+
+        :param request: Request instance for ModifyDBInstanceReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.ModifyDBInstanceReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.ModifyDBInstanceReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyDBInstanceReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyDBInstanceReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyDBInstancesProject(self, request):
         """This API is used to transfer an instance to another project.
 
@@ -726,6 +922,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyReadOnlyGroupConfig(self, request):
+        """This API is used to modify RO group configuration.
+
+        :param request: Request instance for ModifyReadOnlyGroupConfig.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.ModifyReadOnlyGroupConfigRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.ModifyReadOnlyGroupConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyReadOnlyGroupConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyReadOnlyGroupConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def OpenDBExtranetAccess(self, request):
         """This API is used to enable public network access.
 
@@ -754,6 +978,90 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def OpenServerlessDBExtranetAccess(self, request):
+        """This API is used to enable public network access for a PostgreSQL for Serverless instance.
+
+        :param request: Request instance for OpenServerlessDBExtranetAccess.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.OpenServerlessDBExtranetAccessRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.OpenServerlessDBExtranetAccessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("OpenServerlessDBExtranetAccess", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.OpenServerlessDBExtranetAccessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RebalanceReadOnlyGroup(self, request):
+        """This API is used to rebalance the loads of read-only replicas in an RO group. Please note that connections to those read-only replicas will be interrupted transiently; therefore, you should ensure that your application can reconnect to the databases. This operation should be performed with caution.
+
+        :param request: Request instance for RebalanceReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.RebalanceReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.RebalanceReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RebalanceReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RebalanceReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RemoveDBInstanceFromReadOnlyGroup(self, request):
+        """This API is used to remove a read-only replica from an RO group.
+
+        :param request: Request instance for RemoveDBInstanceFromReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.RemoveDBInstanceFromReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.RemoveDBInstanceFromReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RemoveDBInstanceFromReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RemoveDBInstanceFromReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RenewInstance(self, request):
         """This API is used to renew an instance.
 
