@@ -586,6 +586,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAvailableClusterVersion(self, request):
+        """This API is used to obtain all versions that the cluster can upgrade to.
+
+        :param request: Request instance for DescribeAvailableClusterVersion.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeAvailableClusterVersionRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeAvailableClusterVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAvailableClusterVersion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAvailableClusterVersionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClusterAsGroupOption(self, request):
         """Cluster auto scaling configuration
 
@@ -1034,6 +1062,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetUpgradeInstanceProgress(self, request):
+        """This API is used to obtain the current progress of the node upgrade.
+
+        :param request: Request instance for GetUpgradeInstanceProgress.
+        :type request: :class:`tencentcloud.tke.v20180525.models.GetUpgradeInstanceProgressRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.GetUpgradeInstanceProgressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetUpgradeInstanceProgress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetUpgradeInstanceProgressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyClusterAsGroupAttribute(self, request):
         """Modify cluster scaling group attributes
 
@@ -1202,6 +1258,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateClusterVersion(self, request):
+        """This API is used to upgrade the master component of the cluster to the specified version.
+
+        :param request: Request instance for UpdateClusterVersion.
+        :type request: :class:`tencentcloud.tke.v20180525.models.UpdateClusterVersionRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.UpdateClusterVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateClusterVersion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateClusterVersionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpgradeClusterInstances(self, request):
         """This API is used to upgrade one or more work nodes in the cluster.
 
